> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Noise Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC32
```
#include <stdint.h>
#include "noise_hw.h"

sbit NOISE_CS         at RC2_bit;
sbit NOISE_CS_DIR     at TRISC2_bit;
sbit NOISE_INT        at RE8_bit;
sbit NOISE_INT_DIR    at TRISE8_bit;

void system_setup( void )
{
    //GPIOs
    NOISE_CS_DIR  = 0;
    NOISE_INT_DIR = 1;

    //UART
    UART2_Init( 9600 );
    Delay_ms(100);
    UART2_Write_Text( "UART Initialized\r\n" );

    //SPI
    SPI3_Init_Advanced( _SPI_MASTER, _SPI_16_BIT, 1, _SPI_SS_DISABLE,
                    _SPI_DATA_SAMPLE_END, _SPI_CLK_IDLE_LOW,
                    _SPI_IDLE_2_ACTIVE );
    Delay_ms(200);
    UART2_Write_Text( "SPI Initialized\r\n" );

    //ADC
    ADC1_Init();
    Delay_ms(200);
    UART2_Write_Text( "ADC Initialized\r\n" );

    //Noise Click
    noise_init();
    UART2_Write_Text( "Noise Click Initialized\r\n" );

}

```

```
void main()
{
    //Local Decalartions
    uint8_t buffer[20] = { 0 };
    uint32_t value = 0;
    uint16_t threshold = 600;

    //Setup
    system_setup();

    noise_set_threshold( threshold );

    //Loop
    while(1)
    {
        value = ADC1_Read( 8 );
        LongToStr( value, buffer );
        UART2_Write_Text( buffer );
        UART2_Write_Text( "\r\n" );
        Delay_ms(20);
        if( NOISE_INT == 0 );  // Do nothing
        else
            UART2_Write_Text( "Interrupt!!!!!!\r\n" );
    }

}

```

